==> altsys-0.3.zip: xoops_trust_path/libs/altsys/language/persian/modinfo.php <==
<?php


// Appended by Xoops Language Checker -GIJOE- in 2007-03-21 05:34:59
define('_MI_ALTSYS_ADMIN_IN_THEME','Theme set for admin');
define('_MI_ALTSYS_ADMIN_IN_THEMEDSC','Set the name of the theme displaying admin area. Insert a line just after including common.php in mainfile.php<br />include XOOPS_TRUST_PATH.\'/libs/altsys/include/admin_in_theme.inc.php\';<br /> to enable this. This feature works only with XOOPS 2.0.x');

define( '_MI_ALTSYS_MODULENAME' , 'آلت سیس' ) ;
define( '_MI_ALTSYS_MODULEDESC' , 'مدیریت ساده ی سیستم' ) ;

define( '_MI_ALTSYS_MENU_CUSTOMBLOCKS' , 'بلاک دست ساز' ) ;
define( '_MI_ALTSYS_MENU_NEWCUSTOMBLOCK' , '(بلاک دست ساز جدید)' ) ;
define( '_MI_ALTSYS_MENU_MYBLOCKSADMIN' , 'بلاک ماژول ها' ) ;
define( '_MI_ALTSYS_MENU_MYTPLSADMIN' , 'تمپلیت ها' ) ;
define( '_MI_ALTSYS_MENU_COMPILEHOOKADMIN' , 'تمپلیت های پیشرفته' ) ;
define( '_MI_ALTSYS_MENU_MYAVATAR' , 'آواتور ها' ) ;
define( '_MI_ALTSYS_MENU_MYSMILEY' , 'لبخند ها' ) ;

define( '_MI_ALTSYS_ADMINMENU_HFT' , 'باز نویسی منوی مدیریت' ) ;
define( '_MI_ALTSYS_ADMINMENU_HFTDSC' , 'اگر شکل منوی مدیریت شما تغییر نکرد کش cache/adminmenu.php را حذف کنید یا با استفاده از ctrl + F5 کش سیستم را خالی کنید. این ویژگی فقط در زوپس 2.0 کار میکند' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_2COL' , 'نمایش آیکن ماژول ها در دو ردیف' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_NOIMG' , 'نمایش نام ماژول ها به جای آیکن آن ها' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_XCSTY' , 'مشابه XoopsCube Legacy 2.1' ) ;

define( '_MI_ALTSYS_ADMINMENU_IM' , 'کپی کردن لینک های ماژول mymenu در منوی مدیریت' ) ;
define( '_MI_ALTSYS_ADMINMENU_IMDSC' , 'اگر شکل منوی مدیریت شما تغییر نکرد کش cache/adminmenu.php را حذف کنید یا با استفاده از ctrl + F5 کش سیستم را خالی کنید. این ویژگی فقط در زوپس 2.0 کار میکند' ) ;

?>

==> altsys-0.4.zip: xoops_trust_path/libs/altsys/language/persian/modinfo.php <==
<?php



// Appended by Xoops Language Checker -GIJOE- in 2007-03-26 17:09:10
define('_MI_ALTSYS_BNAME_ADMIN_MENU','Admin Menu');
define('_MI_ALTSYS_IMAGES_DIR','Directory for image files');
define('_MI_ALTSYS_IMAGES_DIRDSC','relative path should be set in the module directory. default: images');

// Appended by Xoops Language Checker -GIJOE- in 2007-03-21 05:34:59
define('_MI_ALTSYS_ADMIN_IN_THEME','Theme set for admin');
define('_MI_ALTSYS_ADMIN_IN_THEMEDSC','Set the name of the theme displaying admin area. Insert a line just after including common.php in mainfile.php<br />include XOOPS_TRUST_PATH.\'/libs/altsys/include/admin_in_theme.inc.php\';<br /> to enable this. This feature works only with XOOPS 2.0.x');

define( '_MI_ALTSYS_MODULENAME' , 'آلت سیس' ) ;
define( '_MI_ALTSYS_MODULEDESC' , 'مدیریت ساده ی سیستم' ) ;

define( '_MI_ALTSYS_MENU_CUSTOMBLOCKS' , 'بلاک دست ساز' ) ;
define( '_MI_ALTSYS_MENU_NEWCUSTOMBLOCK' , '(بلاک دست ساز جدید)' ) ;
define( '_MI_ALTSYS_MENU_MYBLOCKSADMIN' , 'بلاک ماژول ها' ) ;
define( '_MI_ALTSYS_MENU_MYTPLSADMIN' , 'تمپلیت ها' ) ;
define( '_MI_ALTSYS_MENU_COMPILEHOOKADMIN' , 'تمپلیت های پیشرفته' ) ;
define( '_MI_ALTSYS_MENU_MYAVATAR' , 'آواتور ها' ) ;
define( '_MI_ALTSYS_MENU_MYSMILEY' , 'لبخند ها' ) ;

define( '_MI_ALTSYS_ADMINMENU_HFT' , 'باز نویسی منوی مدیریت' ) ;
define( '_MI_ALTSYS_ADMINMENU_HFTDSC' , 'اگر شکل منوی مدیریت شما تغییر نکرد کش cache/adminmenu.php را حذف کنید یا با استفاده از ctrl + F5 کش سیستم را خالی کنید. این ویژگی فقط در زوپس 2.0 کار میکند' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_2COL' , 'نمایش آیکن ماژول ها در دو ردیف' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_NOIMG' , 'نمایش نام ماژول ها به جای آیکن آن ها' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_XCSTY' , 'مشابه XoopsCube Legacy 2.1' ) ;

define( '_MI_ALTSYS_ADMINMENU_IM' , 'کپی کردن لینک های ماژول mymenu در منوی مدیریت' ) ;
define( '_MI_ALTSYS_ADMINMENU_IMDSC' , 'اگر شکل منوی مدیریت شما تغییر نکرد کش cache/adminmenu.php را حذف کنید یا با استفاده از ctrl + F5 کش سیستم را خالی کنید. این ویژگی فقط در زوپس 2.0 کار میکند' ) ;

?>
